@@ -184,15 +184,15 @@ class ImgurClient(object):
             account_data['pro_expiration'],
         )
 
-    def get_gallery_favorites(self, username):
+    def get_gallery_favorites(self, username, page=0):
         self.validate_user_context(username)
-        gallery_favorites = self.make_request('GET', 'account/%s/gallery_favorites' % username)
+        gallery_favorites = self.make_request('GET', 'account/%s/gallery_favorites/%d' % (username, page))
 
         return build_gallery_images_and_albums(gallery_favorites)
 
-    def get_account_favorites(self, username):
+    def get_account_favorites(self, username, page=0):
         self.validate_user_context(username)
-        favorites = self.make_request('GET', 'account/%s/favorites' % username)
+        favorites = self.make_request('GET', 'account/%s/favorites/%d' % (username, page))
 
         return build_gallery_images_and_albums(favorites)
 
@@ -586,13 +586,13 @@ class ImgurClient(object):
         fd = open(path, 'rb')
         contents = fd.read()
         b64 = base64.b64encode(contents)
-
         data = {
             'image': b64,
             'type': 'base64',
         }
-
         data.update({meta: config[meta] for meta in set(self.allowed_image_fields).intersection(config.keys())})
+        fd.close()
+        
         return self.make_request('POST', 'upload', data, anon)
 
     def upload_from_url(self, url, config=None, anon=True):
