@@ -1,4 +1,4 @@
-class Comment:
+class Comment(object):
 
     # See documentation at https://api.imgur.com/ for available fields
     def __init__(self, *initial_data, **kwargs):
